@@ -29,16 +29,8 @@
 
 #include <map>
 
-//#define _DEBUG
-
-#ifdef _DEBUG
-#undef THIS_FILE
-static char THIS_FILE[] = __FILE__;
-#define new DEBUG_NEW
-#endif
-
-#ifdef _DEBUG
-FILE *ddbg;
+#ifndef M_PI
+#define M_PI 3.14159265358979323846
 #endif
 
 // extern variables from AudMeS.cpp
@@ -79,10 +71,6 @@ void catcherr(RtAudioError::Type WXUNUSED(type), const std::string &errorText) {
  */
 int inout(void *outputBuffer, void *inputBuffer, unsigned int nBufferFrames,
           double WXUNUSED(streamTime), RtAudioStreamStatus status, void *data) {
-#ifdef _DEBUG
-  fprintf(ddbg, "Jsme tady ");
-#endif
-
   RWAudio *aRWAudioClass = (RWAudio *)data;
   unsigned long i;
 
@@ -144,7 +132,7 @@ int inout(void *outputBuffer, void *inputBuffer, unsigned int nBufferFrames,
   float *outBuf = (float *)outputBuffer;
 
 #ifdef _DEBUG
-  fprintf(ddbg, "\n Frames: %d\n ", nBufferFrames);
+  // fprintf(ddbg, "\n Frames: %d\n ", nBufferFrames);
 #endif
 
   /* calculate the wave form according to the selected shape */
@@ -239,8 +227,8 @@ RWAudio::RWAudio() {
 }
 
 RWAudio::~RWAudio() {
-  m_AudioDriver.stopStream();
-  m_AudioDriver.closeStream();
+  m_AudioDriver->stopStream();
+  m_AudioDriver->closeStream();
 }
 
 // Initialize RtAudio and start audio stream
@@ -285,17 +273,19 @@ int RWAudio::InitSnd(long int oscbuflen, long int spebuflen, std::string &rtinfo
   rtinfo = rtinfo + RtAudio::getVersion() + "\nCompiled APIs:\n";
   for (unsigned int i = 0; i < apis.size(); i++) rtinfo = rtinfo + "  " + apiMap[apis[i]] + "\n";
 
-  rtinfo = rtinfo + "Current API: " + apiMap[m_AudioDriver.getCurrentApi()] + "\n";
+  m_AudioDriver = new RtAudio();
+  rtinfo = rtinfo + "Current API: " + apiMap[m_AudioDriver->getCurrentApi()] + "\n";
 
-  devices = m_AudioDriver.getDeviceCount();
+  devices = m_AudioDriver->getDeviceCount();
   if (devices < 1) return 1;
 
   for (unsigned int i = 0; i < devices; i++) {
-    info = m_AudioDriver.getDeviceInfo(i);
+    info = m_AudioDriver->getDeviceInfo(i);
   }
 
   // start audio streams
-  if (RestartAudio(m_AudioDriver.getDefaultInputDevice(), m_AudioDriver.getDefaultOutputDevice())) {
+  if (RestartAudio(m_AudioDriver->getDefaultInputDevice(),
+                   m_AudioDriver->getDefaultOutputDevice())) {
     return 2;
   }
   return 0;
@@ -303,9 +293,9 @@ int RWAudio::InitSnd(long int oscbuflen, long int spebuflen, std::string &rtinfo
 
 int RWAudio::RestartAudio(int recDevId, int playDevId) {
   // if stream is open (and running), stop it
-  if (m_AudioDriver.isStreamOpen()) {
-    m_AudioDriver.stopStream();
-    m_AudioDriver.closeStream();
+  if (m_AudioDriver->isStreamOpen()) {
+    m_AudioDriver->stopStream();
+    m_AudioDriver->closeStream();
   }
 
   // configure new stream
@@ -324,15 +314,15 @@ int RWAudio::RestartAudio(int recDevId, int playDevId) {
   rtAOptions.flags = 0;
 
   try {
-    m_AudioDriver.openStream(&oParams, &iParams, RTAUDIO_FLOAT32, m_sampleRate, &bufferFrames,
-                             &inout, (void *)this, &rtAOptions, &catcherr);
+    m_AudioDriver->openStream(&oParams, &iParams, RTAUDIO_FLOAT32, m_sampleRate, &bufferFrames,
+                              &inout, (void *)this, &rtAOptions, &catcherr);
   } catch (RtAudioError &e) {
     // std::cerr << '\n' << e.getMessage() << '\n' << std::endl;
     return 1;
   }
 
   try {
-    m_AudioDriver.startStream();
+    m_AudioDriver->startStream();
   } catch (RtAudioError &e) {
     // std::cerr << '\n' << e.getMessage() << '\n' << std::endl;
     return 1;
@@ -348,14 +338,14 @@ int RWAudio::RestartAudio(int recDevId, int playDevId) {
 /********************************************************************/
 int RWAudio::GetRWAudioDevices(RWAudioDevList *play, RWAudioDevList *record) {
   // Determine the number of devices available
-  unsigned int devices = m_AudioDriver.getDeviceCount();
+  unsigned int devices = m_AudioDriver->getDeviceCount();
 
   // Scan through devices for various capabilities
   RtAudio::DeviceInfo info;
   // if stream is open (and running), stop it
-  if (m_AudioDriver.isStreamOpen()) {
-    m_AudioDriver.stopStream();
-    m_AudioDriver.closeStream();
+  if (m_AudioDriver->isStreamOpen()) {
+    m_AudioDriver->stopStream();
+    m_AudioDriver->closeStream();
   }
 
   play->card_info.clear();
@@ -364,7 +354,7 @@ int RWAudio::GetRWAudioDevices(RWAudioDevList *play, RWAudioDevList *record) {
   record->card_pos.clear();
 
   for (unsigned int i = 0; i < devices; i++) {
-    info = m_AudioDriver.getDeviceInfo(i);
+    info = m_AudioDriver->getDeviceInfo(i);
 
     if (info.probed == true) {
       //      std::cout << "device = " << i << "; name: " << info.name << "\n";
@@ -423,12 +413,12 @@ void RWAudio::SetSndDevices(unsigned int irec, unsigned int iplay, unsigned long
   unsigned int cardrec, cardplay;
 
   if (1000 == irec) {
-    cardrec = m_AudioDriver.getDefaultInputDevice();
+    cardrec = m_AudioDriver->getDefaultInputDevice();
   } else {
     cardrec = irec;
   }
   if (1000 == iplay) {
-    cardplay = m_AudioDriver.getDefaultOutputDevice();
+    cardplay = m_AudioDriver->getDefaultOutputDevice();
   } else {
     cardplay = iplay;
   }
